@@ -7,7 +7,7 @@ use warnings;
 use URI;
 use REST::Client;
 
-our $VERSION = '0.02';  # Version of your module
+our $VERSION = '0.03';  # Version of your module
 
 sub new {
     my ($class, %args) = &_grok_args;
@@ -389,7 +389,7 @@ Attaches files to a Jira issue.
 
 =head1 AUTHOR
 
-Your Name <your.email@example.com>
+Kawamura Shingo <pannakoota@gmail.com>
 
 =head1 LICENSE
 
